@@ -13,7 +13,7 @@ class SharedData:
         if Logger.log is None:            
             Logger('SharedData')
         
-        Logger.log.debug('Initializing SharedData %s,%s' % (database,mode))
+        Logger.log.debug('Initializing SharedData %s,%s ...' % (database,mode))
         
         self.database = database
         self.sync_frequency_days = sync_frequency_days
@@ -23,13 +23,13 @@ class SharedData:
         if mode == 'r':
             self.s3read = True
             self.s3write = False
-        elif mode == 'rw':
-            self.s3read = True
-            self.s3write = True
         elif mode == 'w':
             self.s3read = False
             self.s3write = True
-        
+        elif mode == 'rw':
+            self.s3read = True
+            self.s3write = True
+                
         # last download sync datetime
         self.lastsync = pd.DataFrame([])
         self.lastsyncfpath = Path(os.environ['DATABASE_FOLDER']) / (database + '/lastsync.txt')
@@ -47,12 +47,12 @@ class SharedData:
         # Symbols collections metadata
         self.metadata = {}
 
-        # DATASET
-        # TODO: UPLOAD DATASET IF CHANGED
-        md = Metadata('DATASET/DATASET_' + database)
-        self.dataset = md.static
+        # DATASET        
+        self.dataset_metadata = Metadata('DATASET/DATASET_' + database,\
+            mode=mode,sync_frequency_days=sync_frequency_days)
+        self.dataset = self.dataset_metadata.static
         
-        Logger.log.debug('Shared data initialized!')
+        Logger.log.debug('Initializing SharedData %s,%s DONE!' % (database,mode))
 
     def __setitem__(self, feeder, value):
         self.data[feeder] = value
