@@ -117,16 +117,16 @@ def S3SyncDownloadMetadata(pathpkl,name):
     return success
 
 def S3Upload(localfilepath):
+    localfilepath = str(localfilepath).replace('\\','/')                
     Logger.log.debug('Uploading to S3 '+str(localfilepath)+' ...')
     try:        
         remotefilepath = str(localfilepath).replace(\
             os.environ['DATABASE_FOLDER'],os.environ['S3_BUCKET'])   
-        remotefilepath = remotefilepath.replace('\\','/')
-        localfilepath = str(localfilepath).replace('\\','/')        
+        remotefilepath = remotefilepath.replace('\\','/')        
         session = boto3.Session(profile_name='s3readwrite')   
         s3 = session.resource('s3')
         bucket = s3.Bucket(os.environ['S3_BUCKET'].replace('s3://',''))
         bucket.upload_file(localfilepath,remotefilepath.replace(os.environ['S3_BUCKET'],'')[1:])
-        Logger.log.debug('Uploading to S3 '+localfilepath+' DONE!')
+        Logger.log.debug('Uploading to S3 '+str(localfilepath)+' DONE!')
     except Exception as e:
         Logger.log.error('Uploading to S3 '+localfilepath+' ERROR! %s' % str(e))        
\ No newline at end of file
